@@ -7,6 +7,8 @@ from django.test import Client, RequestFactory, TestCase
 from django.urls import reverse
 from django.utils import timezone
 
+from cms.contacts.templatetags.unicms_contacts import load_contact
+from cms.contacts.tests import ContactUnitTest
 from cms.carousels.templatetags.unicms_carousels import load_carousel
 from cms.carousels.tests import CarouselUnitTest
 from cms.contexts.tests import ContextUnitTest
@@ -23,7 +25,7 @@ from cms.templates.placeholders import *
 from cms.templates.tests import TemplateUnitTest
 from cms.templates.templatetags.unicms_templates import blocks_in_position
 
-from . models import (Page, PageBlock, PageCarousel,
+from . models import (Page, PageBlock, PageCarousel, PageContact,
                       PageHeading, PageHeadingLocalization, PageLink,
                       PageLocalization, PageMedia, PageMediaCollection,
                       PageMenu, PageRelated)
@@ -104,6 +106,14 @@ class PageUnitTest(TestCase):
                                          is_active=1)
         pc.__str__()
 
+        # page contact
+        contact = ContactUnitTest.create_contact()
+        pco = PageContact.objects.create(page = obj,
+                                        contact=contact,
+                                        section='1-right-b',
+                                        is_active=1)
+        pco.__str__()
+
         # page heading
         phead = PageHeading.objects.create(page = obj,
                                         title= 'page heading',
@@ -241,6 +251,22 @@ class PageUnitTest(TestCase):
         assert 'italia_carousel' not in lm
 
 
+    @classmethod
+    def test_page_load_contact(cls):
+        obj = cls.create_page(date_end=timezone.localtime())
+        req = RequestFactory().get('/')
+        template_context = dict(request=req,
+                                webpath=obj.webpath,
+                                page=obj)
+
+        data = dict(context=template_context,
+                    section='1-right-b',
+                    template='that.html')
+
+        lm = load_contact(**data)
+        assert lm
+
+
     # templatetag
     @classmethod
     def test_load_page_title(cls):
@@ -385,6 +411,31 @@ class PageUnitTest(TestCase):
         lm = block.render()
         assert lm
 
+    # placeholders
+    @classmethod
+    def test_load_contact_placeholder(cls):
+        page = cls.create_page()
+        webpath = page.webpath
+        req = RequestFactory().get('/')
+
+        block = ContactPlaceholderBlock(
+            request = req,
+            webpath = webpath,
+            page = page,
+            content = '{"template" :"that_template.html"}'
+        )
+
+        template_block = TemplateBlock.objects.create(
+            name = 'contact test',
+            type = 'cms.templates.blocks.ContactPlaceholderBlock',
+            is_active = True
+        )
+        page_block = PageBlock.objects.create(page=page,
+                                              block = template_block,
+                                              is_active=1)
+        lm = block.render()
+        assert lm
+
     # placeholders
     @classmethod
     def test_load_link_placeholder(cls):
